stsynphot
=========

.. image:: https://img.shields.io/badge/ascl-2010.003-blue.svg?colorB=262255
   :target: https://ascl.net/2010.003
   :alt: ASCL 2010.003

.. image:: https://zenodo.org/badge/12412342.svg
   :target: https://zenodo.org/doi/10.5281/zenodo.5020767
   :alt: DOI: 10.5281/zenodo.5020767

.. image:: https://readthedocs.org/projects/stsynphot/badge/?version=latest
    :target: https://stsynphot.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://github.com/spacetelescope/stsynphot_refactor/actions/workflows/ci_workflows.yml/badge.svg?branch=master
    :target: https://github.com/spacetelescope/stsynphot_refactor/actions/workflows/ci_workflows.yml
    :alt: Github Actions CI Status

.. image:: https://codecov.io/gh/spacetelescope/stsynphot_refactor/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/spacetelescope/stsynphot_refactor
    :alt: Coverage results

This is a replacement for IRAF STSDAS SYNPHOT and ASTROLIB PYSYNPHOT, utilizing Astropy
covering instrument specific portions of the old packages for HST.
